@@ -2,25 +2,25 @@
 {% import 'macros/schemas/privilege.macros' as PRIVILEGE %}
 {% if data %}
 {% set name = o_data.name %}
-{% if data.name %}{% if data.name != o_data.name %}
+{% if data.name %}
+{% if data.name != o_data.name %}
 ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, o_data.name) }}
     RENAME TO {{ conn|qtIdent(data.name) }};
 {% set name = data.name %}
-{% endif %}{% endif %}
+{% endif %}
+{% endif -%}
 {% if data.owner %}
 
 ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }}
     OWNER TO {{ data.owner }};
-{% endif %}
+{% endif -%}
 {% if data.columns %}
 {% for c in data.columns.deleted %}
-{% if (not c.inheritedfrom or c.inheritedfrom =='' or  c.inheritedfrom == None or  c.inheritedfrom == 'None' ) %}
+
 ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }}
     DROP COLUMN {{conn|qtIdent(c.attname)}};
-{% endif %}
 {% endfor -%}
 {% for c in data.columns.added %}
-{% if (not c.inheritedfrom or c.inheritedfrom =='' or  c.inheritedfrom == None or  c.inheritedfrom == 'None' ) %}
 
 ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }}
     ADD COLUMN {{conn|qtIdent(c.attname)}} {{ conn|qtTypeIdent(c.datatype) }}{% if c.typlen %}({{c.typlen}}{% if c.precision %}, {{c.precision}}{% endif %}){% endif %}{% if c.isArrayType %}[]{% endif %}
@@ -31,7 +31,6 @@ ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }}
 {% if c.attnotnull %} NOT NULL{% else %} NULL{% endif %}
 {% if c.typdefault is defined and c.typdefault is not none %} DEFAULT {{c.typdefault}}{% endif %}
 {% if c.collname %} COLLATE {{c.collname}}{% endif %};
-{% endif %}
 {% endfor -%}
 {% for c in data.columns.changed %}
 {% set col_name = o_data['columns'][c.attnum]['attname'] %}
@@ -84,52 +83,19 @@ ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }}
 {% endfor %}
 {% endif -%}
 {% endfor %}
-{% endif %}
-{% if data.inherits and data.inherits|length > 0%}
-{% if o_data.inherits == None or o_data.inherits == 'None' %}
-{% set inherits = '' %}
-{% else %}
-{% set inherits = o_data.inherits %}
-{% endif %}
-{% for i in data.inherits %}
-{% if i not in inherits %}{% if i %}
-
-ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }} INHERIT {{i}};
-{% endif %}
-{% endif %}
-{% endfor %}
-{% endif %}
-{% if o_data.inherits and 'inherits' in data %}
-{% if data.inherits == None or data.inherits == 'None' %}
-{% set inherits = '' %}
-{% else %}
-{% set inherits = data.inherits %}
-{% endif %}
-{% for i in o_data.inherits %}{% if i not in inherits %}{% if i %}
-
-ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }} NO INHERIT {{i}};{% endif %}
-{% endif %}
-{% endfor %}
-{% endif %}
+{% endif -%}
 {% if data.constraints %}
 {% for c in data.constraints.deleted %}
 
 ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }}
     DROP CONSTRAINT {{conn|qtIdent(c.conname)}};
-{% endfor -%}
+{% endfor %}
 {% for c in data.constraints.added %}
 
 ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }}
-    ADD CONSTRAINT {{ conn|qtIdent(c.conname) }} CHECK ({{ c.consrc }}){% if not c.convalidated %} NOT VALID{% endif %}{% if c.connoinherit %} NO INHERIT{% endif %};
+    ADD CONSTRAINT {{conn|qtIdent(c.conname)}} {% if c.consrc %} CHECK ({{c.consrc}}){% endif %} {% if c.connoinherit %} NO INHERIT{% endif %};
 {% endfor %}
-{% for c in data.constraints.changed %}
-{% if c.convalidated %}
-
-ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }}
-    VALIDATE CONSTRAINT {{ conn|qtIdent(c.conname) }};
-{% endif %}
-{% endfor %}
-{% endif %}
+{% endif -%}
 {% if data.ftoptions %}
 {% for o in data.ftoptions.deleted %}
 {% if o.option and o.value %}
@@ -153,30 +119,6 @@ ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }}
 {% endif %}
 {% endfor %}
 {% endif -%}
-{% set seclabels = data.seclabels %}
-{% if 'deleted' in seclabels and seclabels.deleted|length > 0 %}
-{% for r in seclabels.deleted %}
-
-{{ SECLABEL.UNSET(conn, 'FOREIGN TABLE', name, r.provider, o_data.basensp) }}
-{% endfor %}
-{% endif %}
-{% if 'added' in seclabels and seclabels.added|length > 0 %}
-{% for r in seclabels.added %}
-
-{{ SECLABEL.SET(conn, 'FOREIGN TABLE', name, r.provider, r.label, o_data.basensp) }}
-{% endfor %}
-{% endif %}
-{% if 'changed' in seclabels and seclabels.changed|length > 0 %}
-{% for r in seclabels.changed %}
-
-{{ SECLABEL.SET(conn, 'FOREIGN TABLE', name, r.provider, r.label, o_data.basensp) }}
-{% endfor %}
-{% endif -%}
-{% if data.description is defined and data.description != o_data.description%}
-
-COMMENT ON FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }}
-IS {{ data.description|qtLiteral }};
-{% endif -%}
 {% if data.acl %}
 {% if 'deleted' in data.acl %}
 {% for priv in data.acl.deleted %}
@@ -199,6 +141,30 @@ IS {{ data.description|qtLiteral }};
 {% endfor %}
 {% endif %}
 {% endif -%}
+{% set seclabels = data.seclabels %}
+{% if 'deleted' in seclabels and seclabels.deleted|length > 0 %}
+{% for r in seclabels.deleted %}
+
+{{ SECLABEL.UNSET(conn, 'FOREIGN TABLE', name, r.provider, o_data.basensp) }}
+{% endfor %}
+{% endif -%}
+{% if 'added' in seclabels and seclabels.added|length > 0 %}
+{% for r in seclabels.added %}
+
+{{ SECLABEL.SET(conn, 'FOREIGN TABLE', name, r.provider, r.label, o_data.basensp) }}
+{% endfor %}
+{% endif -%}
+{% if 'changed' in seclabels and seclabels.changed|length > 0 %}
+{% for r in seclabels.changed %}
+
+{{ SECLABEL.SET(conn, 'FOREIGN TABLE', name, r.provider, r.label, o_data.basensp) }}
+{% endfor %}
+{% endif -%}
+{% if data.description is defined and data.description != o_data.description%}
+
+COMMENT ON FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }}
+    IS {{ data.description|qtLiteral }};
+{% endif -%}
 {% if data.basensp %}
 
 ALTER FOREIGN TABLE {{ conn|qtIdent(o_data.basensp, name) }}
